// Copyright (C) 2016 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0-only WITH Qt-GPL-exception-1.0

#ifndef TESTMULTIPLEINHERITANCE_H
#define TESTMULTIPLEINHERITANCE_H

#include <QtCore/qobject.h>

class AbstractMetaBuilder;

class TestMultipleInheritance : public QObject
{
    Q_OBJECT
    private slots:
        void testVirtualClass();
};

#endif
